pub struct DescribeHostState { /* private fields */ }Trait Implementations
Sourceimpl Default for DescribeHostState
impl Default for DescribeHostState
Sourceimpl WasiHttpView for DescribeHostState
impl WasiHttpView for DescribeHostState
Sourcefn ctx(&mut self) -> &mut WasiHttpCtx
fn ctx(&mut self) -> &mut WasiHttpCtx
Returns a mutable reference to the WASI HTTP context.
Sourcefn table(&mut self) -> &mut ResourceTable
fn table(&mut self) -> &mut ResourceTable
Returns the table used to manage resources.
Sourcefn new_incoming_request<B>(
&mut self,
scheme: Scheme,
req: Request<B>,
) -> Result<Resource<HostIncomingRequest>, Error>
fn new_incoming_request<B>( &mut self, scheme: Scheme, req: Request<B>, ) -> Result<Resource<HostIncomingRequest>, Error>
Create a new incoming request resource.
Sourcefn new_response_outparam(
&mut self,
result: Sender<Result<Response<UnsyncBoxBody<Bytes, ErrorCode>>, ErrorCode>>,
) -> Result<Resource<HostResponseOutparam>, Error>
fn new_response_outparam( &mut self, result: Sender<Result<Response<UnsyncBoxBody<Bytes, ErrorCode>>, ErrorCode>>, ) -> Result<Resource<HostResponseOutparam>, Error>
Create a new outgoing response resource.
Sourcefn send_request(
&mut self,
request: Request<UnsyncBoxBody<Bytes, ErrorCode>>,
config: OutgoingRequestConfig,
) -> Result<HostFutureIncomingResponse, HttpError>
fn send_request( &mut self, request: Request<UnsyncBoxBody<Bytes, ErrorCode>>, config: OutgoingRequestConfig, ) -> Result<HostFutureIncomingResponse, HttpError>
Send an outgoing request.
Sourcefn is_forbidden_header(&mut self, name: &HeaderName) -> bool
fn is_forbidden_header(&mut self, name: &HeaderName) -> bool
Whether a given header should be considered forbidden and not allowed.
Sourcefn outgoing_body_buffer_chunks(&mut self) -> usize
fn outgoing_body_buffer_chunks(&mut self) -> usize
Number of distinct write calls to the outgoing body’s output-stream
that the implementation will buffer.
Default: 1.
Sourcefn outgoing_body_chunk_size(&mut self) -> usize
fn outgoing_body_chunk_size(&mut self) -> usize
Maximum size allowed in a write call to the outgoing body’s output-stream.
Default: 1024 * 1024.
Sourceimpl WasiView for DescribeHostState
impl WasiView for DescribeHostState
Sourcefn ctx(&mut self) -> WasiCtxView<'_>
fn ctx(&mut self) -> WasiCtxView<'_>
Yields mutable access to the
WasiCtx configuration used for this
context.Auto Trait Implementations
impl Freeze for DescribeHostState
impl !RefUnwindSafe for DescribeHostState
impl Send for DescribeHostState
impl !Sync for DescribeHostState
impl Unpin for DescribeHostState
impl UnsafeUnpin for DescribeHostState
impl !UnwindSafe for DescribeHostState