pub struct GeneratedSetup {
pub setup_yaml: String,
pub secret_requirements_json: String,
}Expand description
The two generated asset bodies, ready to write into the pack.
Fields
setup_yaml: Stringsecret_requirements_json: StringTrait Implementations
Sourceimpl Clone for GeneratedSetup
impl Clone for GeneratedSetup
Sourcefn clone(&self) -> GeneratedSetup
fn clone(&self) -> GeneratedSetup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GeneratedSetup
impl Debug for GeneratedSetup
Sourceimpl PartialEq for GeneratedSetup
impl PartialEq for GeneratedSetup
Sourcefn eq(&self, other: &GeneratedSetup) -> bool
fn eq(&self, other: &GeneratedSetup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GeneratedSetup