pub struct ToolSecretReq {
pub key: String,
pub required: bool,
pub description: Option<String>,
pub format: Option<String>,
}Expand description
One secret a tool needs, as declared in the extension’s describe.json
contributions.tools[].secret_requirements.
Fields
key: Stringrequired: booldescription: Option<String>format: Option<String>Trait Implementations
Sourceimpl Clone for ToolSecretReq
impl Clone for ToolSecretReq
Sourcefn clone(&self) -> ToolSecretReq
fn clone(&self) -> ToolSecretReq
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolSecretReq
impl Debug for ToolSecretReq
Sourceimpl<'de> Deserialize<'de> for ToolSecretReq
impl<'de> Deserialize<'de> for ToolSecretReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ToolSecretReq
impl PartialEq for ToolSecretReq
Sourcefn eq(&self, other: &ToolSecretReq) -> bool
fn eq(&self, other: &ToolSecretReq) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ToolSecretReq